"""ecom URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path
from website.views import home,login,signup,profile,allusers,logout,singleuser,edituser,deleteuser

urlpatterns = [
    path('admin/', admin.site.urls),
    path('',home,name="home"),
    path('login/',login,name="login"),
    path('signup/',signup,name="signup"),
    path('profile/',profile,name="profile"),
    path('allusers/',allusers,name="allusers"),
    path('logout/',logout,name="logout"),
    path('singleuser/<int:id>/',singleuser,name="singleuser"),
    path('edituser/<int:id>/',edituser,name="edituser"),
    path('deleteuser/<int:id>/',deleteuser,name="deleteuser"),
]



# Generated by Django 2.2.2 on 2019-06-14 06:02

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Users',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=80)),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('password', models.CharField(max_length=50)),
                ('mobile', models.CharField(max_length=20)),
            ],
        ),
    ]



from django.shortcuts import render
from .models import Users

# Create your views here.

def home(request):
    return render(request,'home.html')

def login(request):
    if request.method == 'GET':
        return render(request,'login.html')
    if request.method == 'POST':
        try:
            email = request.POST.get('email')
            password = request.POST.get('password')
            #print(email,password)
            user = Users.objects.get(email=email)
            if user.password == password:
                request.session["user_email"] = email
                return render(request,'profile.html')
            else:
                return render(request,'login.html',{'msg':'Enter Correct Password','tag':'danger'})
        except Exception:
            return render(request,'login.html',{'msg':'Enter Correct Email','tag':'danger'})
def signup(request):
    if request.method == 'GET':
        return render(request,'signup.html')
    if request.method == 'POST':
        try:
            name = request.POST.get('name')
            email = request.POST.get('email')
            password = request.POST.get('password')
            mobile = request.POST.get('mobile')
            #print(name,email,password,mobile)
            user = Users()
            user.name = name
            user.email = email
            user.password = password
            user.mobile = mobile
            user.save()
            return render(request,'signup.html',{'msg':'Successfully Signup','tag':'success'})
        except Exception:
            return render(request,'signup.html',{'msg':'Error on Signup','tag':'danger'})

def profile(request):
    return render(request,'profile.html')

def allusers (request):
    users_list = Users.objects.all()
    return render(request,'allusers.html',{'list':users_list})

def singleuser(request,id):
    user = Users.objects.get(id=id)
    return render(request,'singleuser.html',{'user':user})

def edituser(request,id):
    if request.method == 'GET':
        user = Users.objects.get(id=id)
        return render(request,'edituser.html',{'user':user})
    if request.method == 'POST':
        name = request.POST.get('name')
        email = request.POST.get('email')
        password = request.POST.get('password')
        mobile = request.POST.get('mobile')
        user = Users.objects.get(id=id)
        user.name = name
        user.password = password
        user.mobile = mobile
        user.save()
        users_list = Users.objects.all()
        return render(request,'allusers.html',{'list':users_list})

def deleteuser(request,id):
    Users.objects.filter(id=id).delete()
    users_list = Users.objects.all()
    return render(request,'allusers.html',{'list':users_list})

def logout(request):
    del request.session["user_email"]
    return render(request,'login.html')


from django.db import models

# Create your models here.

class Users(models.Model):
    name = models.CharField(max_length=80)
    email = models.EmailField(unique=True)
    password = models.CharField(max_length=50)
    mobile = models.CharField(max_length=20)



from setuptools import setup, find_packages

setup(
    name='seele',
    version='0.1.1',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'django>=5.0.6',
	'django-bootstrap4>=23.4',
	'sqlparse>=0.3.1'
    ],
    entry_points={
        'console_scripts': [
            'seele_start=seele_app.entrypoint:main',
        ],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
    ],
    author='Nicholas DeSanctis',
    author_email='nickdesanctis17@gmail.com',
    description='SEELE Web Development server package',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/JMalegni/DisasterPrepApp',
    project_urls={
        'Source': 'https://github.com/JMalegni/DisasterPrepApp',
    },
)
